Free convection to immersed bodies (ht.conv_free_immersed)
==========================================================

.. automodule:: ht.conv_free_immersed
    :members:
    :undoc-members:
    :show-inheritance:
